import { Component, OnInit } from '@angular/core';
import { MatButtonModule } from '@angular/material/button';
import { MatTableModule } from '@angular/material/table';
import UserData from '@core/auth/UserData';
import {AdministratablePlayer, AdminService, PlayerFilter} from '@core/server';

@Component({
    selector: 'app-admin-overview',
    templateUrl: './admin-overview.component.html',
    styleUrls: ['./admin-overview.component.scss'],
    standalone: true,
    imports: [MatTableModule, MatButtonModule]
})
export class AdminOverviewComponent implements OnInit {
    displayedColumns: Array<string> = ['username', 'ban'];
    userList: Array<AdministratablePlayer> = [];

    constructor(private adminService: AdminService) {}

    ngOnInit(): void {
        this.fetchPlayers();
    }

    fetchPlayers(): void {
        const filter: PlayerFilter = {
            page: 0,
            pageSize: 32,
            order: PlayerFilter.OrderEnum.Ascending,
            username: '',
            sortBy: 'username'
        };
        this.adminService.getAllPlayers(filter).subscribe(
            (players) => {
                this.userList = players;
            },
            (error) => {
                console.error('Error fetching players:', error);
            }
        );
    }

    banPlayer(user: UserData): void {
        console.log(`Banning user: ${user.username}`);
    }
}
